@@ -859,24 +859,26 @@ def pbdDict_bisosRoot(
     symLink('apps/bxtex', 'git/bxRepos/bxlcnt/bxtex')
     symLink('apps/comeega', 'git/bxRepos/bisos/comeega')
     symLink('apps/defaults', 'git/bxRepos/bisos/defaults')    
+
+    symLink('panels', 'git/bxRepos/blee-binders')
     
-    directory('panels')
-    directory('panels/bisos')
-    directory('panels/blee')
-    directory('panels/bxde')            
-    symLink('panels/bisos/core', 'git/bxRepos/blee-binders/bisos-core')
-    symLink('panels/bisos/dev', 'git/bxRepos/blee-binders/bisos-dev')
-    symLink('panels/bisos/model', 'git/bxRepos/blee-binders/bisos-model')        
-    symLink('panels/blee/core', 'git/bxRepos/blee-binders/blee-core')
-    symLink('panels/blee/dev', 'git/bxRepos/blee-binders/blee-dev')
-    symLink('panels/blee/model', 'git/bxRepos/blee-binders/blee-model')        
-    symLink('panels/bxde/core', 'git/bxRepos/blee-binders/bxde-core')
-    symLink('panels/bxde/dev', 'git/bxRepos/blee-binders/bxde-dev')
-    symLink('panels/bisos-apps', 'git/bxRepos/blee-binders/bisos-apps')
-    symLink('panels/bisos-periphery', 'git/bxRepos/blee-binders/bisos-periphery')
-    symLink('panels/espoused', 'git/bxRepos/blee-binders/espoused')
-    symLink('panels/non-libre-halaal', 'git/bxRepos/blee-binders/non-libre-halaal')    
-    symLink('panels/panelsRoot', 'git/bxRepos/blee-binders/panelsRoot')    
+    # directory('panels')
+    # directory('panels/bisos')
+    # directory('panels/blee')
+    # directory('panels/bxde')            
+    # symLink('panels/bisos/core', 'git/bxRepos/blee-binders/bisos-core')
+    # symLink('panels/bisos/dev', 'git/bxRepos/blee-binders/bisos-dev')
+    # symLink('panels/bisos/model', 'git/bxRepos/blee-binders/bisos-model')        
+    # symLink('panels/blee/core', 'git/bxRepos/blee-binders/blee-core')
+    # symLink('panels/blee/dev', 'git/bxRepos/blee-binders/blee-dev')
+    # symLink('panels/blee/model', 'git/bxRepos/blee-binders/blee-model')        
+    # symLink('panels/bxde/core', 'git/bxRepos/blee-binders/bxde-core')
+    # symLink('panels/bxde/dev', 'git/bxRepos/blee-binders/bxde-dev')
+    # symLink('panels/bisos-apps', 'git/bxRepos/blee-binders/bisos-apps')
+    # symLink('panels/bisos-periphery', 'git/bxRepos/blee-binders/bisos-periphery')
+    # symLink('panels/espoused', 'git/bxRepos/blee-binders/espoused')
+    # symLink('panels/non-libre-halaal', 'git/bxRepos/blee-binders/non-libre-halaal')    
+    # symLink('panels/panelsRoot', 'git/bxRepos/blee-binders/panelsRoot')    
 
     directory('gatherer')
     directory('gatherer/here')
